# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: EventHub.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='EventHub.proto',
  package='predix.eventhub',
  syntax='proto3',
  serialized_pb=_b('\n\x0e\x45ventHub.proto\x12\x0fpredix.eventhub\"+\n\tTimestamp\x12\x0f\n\x07seconds\x18\x01 \x01(\x03\x12\r\n\x05nanos\x18\x02 \x01(\x05\"\x81\x02\n\x07Message\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\x0c\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12\x30\n\x04tags\x18\x04 \x03(\x0b\x32\".predix.eventhub.Message.TagsEntry\x12\x0b\n\x03key\x18\x05 \x01(\x0c\x12\r\n\x05topic\x18\x06 \x01(\t\x12\x11\n\tpartition\x18\x07 \x01(\x05\x12\x0e\n\x06offset\x18\x08 \x01(\x03\x12-\n\ttimestamp\x18\t \x01(\x0b\x32\x1a.predix.eventhub.Timestamp\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb8\x02\n\x03\x41\x63k\x12\n\n\x02id\x18\x01 \x01(\t\x12/\n\x0bstatus_code\x18\x02 \x01(\x0e\x32\x1a.predix.eventhub.AckStatus\x12\x0c\n\x04\x64\x65sc\x18\x03 \x01(\t\x12\r\n\x05topic\x18\x04 \x01(\t\x12\x11\n\tpartition\x18\x05 \x01(\x05\x12\x0e\n\x06offset\x18\x06 \x01(\x03\x12-\n\ttimestamp\x18\x07 \x01(\x0b\x32\x1a.predix.eventhub.Timestamp\x12\x0c\n\x04\x62ody\x18\x08 \x01(\x0c\x12\x0f\n\x07zone_id\x18\t \x01(\t\x12,\n\x04tags\x18\n \x03(\x0b\x32\x1e.predix.eventhub.Ack.TagsEntry\x12\x0b\n\x03key\x18\x0b \x01(\x0c\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x08Messages\x12%\n\x03msg\x18\x01 \x03(\x0b\x32\x18.predix.eventhub.Message\"=\n\x0ePublishRequest\x12+\n\x08messages\x18\x01 \x01(\x0b\x32\x19.predix.eventhub.Messages\"B\n\x13SubscriptionMessage\x12+\n\x08messages\x18\x01 \x01(\x0b\x32\x19.predix.eventhub.Messages\"4\n\x0fPublishResponse\x12!\n\x03\x61\x63k\x18\x01 \x03(\x0b\x32\x14.predix.eventhub.Ack\"9\n\x14SubscriptionResponse\x12!\n\x03\x61\x63k\x18\x01 \x03(\x0b\x32\x14.predix.eventhub.Ack\"5\n\x10SubscriptionAcks\x12!\n\x03\x61\x63k\x18\x01 \x03(\x0b\x32\x14.predix.eventhub.Ack\"O\n\x13SubscriptionRequest\x12\x0f\n\x07zone_id\x18\x01 \x01(\t\x12\x12\n\nsubscriber\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t*M\n\tAckStatus\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x00\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x01\x12\x15\n\x11REQUEST_TOO_LARGE\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x32\\\n\tPublisher\x12O\n\x04send\x12\x1f.predix.eventhub.PublishRequest\x1a .predix.eventhub.PublishResponse\"\x00(\x01\x30\x01\x32\x91\x02\n\nSubscriber\x12M\n\x07receive\x12$.predix.eventhub.SubscriptionRequest\x1a\x18.predix.eventhub.Message\"\x00\x30\x01\x12X\n\x0freceiveWithAcks\x12%.predix.eventhub.SubscriptionResponse\x1a\x18.predix.eventhub.Message\"\x00(\x01\x30\x01\x12Z\n\tsubscribe\x12!.predix.eventhub.SubscriptionAcks\x1a$.predix.eventhub.SubscriptionMessage\"\x00(\x01\x30\x01\x42+\n\x16\x63om.ge.predix.eventhubB\x0f\x45ventHubServiceP\x01\x62\x06proto3')
)

_ACKSTATUS = _descriptor.EnumDescriptor(
  name='AckStatus',
  full_name='predix.eventhub.AckStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACCEPTED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BAD_REQUEST', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REQUEST_TOO_LARGE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1086,
  serialized_end=1163,
)
_sym_db.RegisterEnumDescriptor(_ACKSTATUS)

AckStatus = enum_type_wrapper.EnumTypeWrapper(_ACKSTATUS)
ACCEPTED = 0
BAD_REQUEST = 1
REQUEST_TOO_LARGE = 2
FAILED = 3



_TIMESTAMP = _descriptor.Descriptor(
  name='Timestamp',
  full_name='predix.eventhub.Timestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='predix.eventhub.Timestamp.seconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nanos', full_name='predix.eventhub.Timestamp.nanos', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=78,
)


_MESSAGE_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='predix.eventhub.Message.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='predix.eventhub.Message.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='predix.eventhub.Message.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=338,
)

_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='predix.eventhub.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='predix.eventhub.Message.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='body', full_name='predix.eventhub.Message.body', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='predix.eventhub.Message.zone_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='predix.eventhub.Message.tags', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key', full_name='predix.eventhub.Message.key', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='topic', full_name='predix.eventhub.Message.topic', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partition', full_name='predix.eventhub.Message.partition', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='predix.eventhub.Message.offset', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='predix.eventhub.Message.timestamp', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_MESSAGE_TAGSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=338,
)


_ACK_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='predix.eventhub.Ack.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='predix.eventhub.Ack.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='predix.eventhub.Ack.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=338,
)

_ACK = _descriptor.Descriptor(
  name='Ack',
  full_name='predix.eventhub.Ack',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='predix.eventhub.Ack.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='predix.eventhub.Ack.status_code', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desc', full_name='predix.eventhub.Ack.desc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='topic', full_name='predix.eventhub.Ack.topic', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='partition', full_name='predix.eventhub.Ack.partition', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='predix.eventhub.Ack.offset', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='predix.eventhub.Ack.timestamp', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='body', full_name='predix.eventhub.Ack.body', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='predix.eventhub.Ack.zone_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='predix.eventhub.Ack.tags', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='key', full_name='predix.eventhub.Ack.key', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_ACK_TAGSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=341,
  serialized_end=653,
)


_MESSAGES = _descriptor.Descriptor(
  name='Messages',
  full_name='predix.eventhub.Messages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msg', full_name='predix.eventhub.Messages.msg', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=704,
)


_PUBLISHREQUEST = _descriptor.Descriptor(
  name='PublishRequest',
  full_name='predix.eventhub.PublishRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='predix.eventhub.PublishRequest.messages', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=706,
  serialized_end=767,
)


_SUBSCRIPTIONMESSAGE = _descriptor.Descriptor(
  name='SubscriptionMessage',
  full_name='predix.eventhub.SubscriptionMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='predix.eventhub.SubscriptionMessage.messages', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=769,
  serialized_end=835,
)


_PUBLISHRESPONSE = _descriptor.Descriptor(
  name='PublishResponse',
  full_name='predix.eventhub.PublishResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ack', full_name='predix.eventhub.PublishResponse.ack', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=837,
  serialized_end=889,
)


_SUBSCRIPTIONRESPONSE = _descriptor.Descriptor(
  name='SubscriptionResponse',
  full_name='predix.eventhub.SubscriptionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ack', full_name='predix.eventhub.SubscriptionResponse.ack', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=891,
  serialized_end=948,
)


_SUBSCRIPTIONACKS = _descriptor.Descriptor(
  name='SubscriptionAcks',
  full_name='predix.eventhub.SubscriptionAcks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ack', full_name='predix.eventhub.SubscriptionAcks.ack', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=950,
  serialized_end=1003,
)


_SUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='SubscriptionRequest',
  full_name='predix.eventhub.SubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='predix.eventhub.SubscriptionRequest.zone_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subscriber', full_name='predix.eventhub.SubscriptionRequest.subscriber', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='predix.eventhub.SubscriptionRequest.instance_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1005,
  serialized_end=1084,
)

_MESSAGE_TAGSENTRY.containing_type = _MESSAGE
_MESSAGE.fields_by_name['tags'].message_type = _MESSAGE_TAGSENTRY
_MESSAGE.fields_by_name['timestamp'].message_type = _TIMESTAMP
_ACK_TAGSENTRY.containing_type = _ACK
_ACK.fields_by_name['status_code'].enum_type = _ACKSTATUS
_ACK.fields_by_name['timestamp'].message_type = _TIMESTAMP
_ACK.fields_by_name['tags'].message_type = _ACK_TAGSENTRY
_MESSAGES.fields_by_name['msg'].message_type = _MESSAGE
_PUBLISHREQUEST.fields_by_name['messages'].message_type = _MESSAGES
_SUBSCRIPTIONMESSAGE.fields_by_name['messages'].message_type = _MESSAGES
_PUBLISHRESPONSE.fields_by_name['ack'].message_type = _ACK
_SUBSCRIPTIONRESPONSE.fields_by_name['ack'].message_type = _ACK
_SUBSCRIPTIONACKS.fields_by_name['ack'].message_type = _ACK
DESCRIPTOR.message_types_by_name['Timestamp'] = _TIMESTAMP
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
DESCRIPTOR.message_types_by_name['Ack'] = _ACK
DESCRIPTOR.message_types_by_name['Messages'] = _MESSAGES
DESCRIPTOR.message_types_by_name['PublishRequest'] = _PUBLISHREQUEST
DESCRIPTOR.message_types_by_name['SubscriptionMessage'] = _SUBSCRIPTIONMESSAGE
DESCRIPTOR.message_types_by_name['PublishResponse'] = _PUBLISHRESPONSE
DESCRIPTOR.message_types_by_name['SubscriptionResponse'] = _SUBSCRIPTIONRESPONSE
DESCRIPTOR.message_types_by_name['SubscriptionAcks'] = _SUBSCRIPTIONACKS
DESCRIPTOR.message_types_by_name['SubscriptionRequest'] = _SUBSCRIPTIONREQUEST
DESCRIPTOR.enum_types_by_name['AckStatus'] = _ACKSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Timestamp = _reflection.GeneratedProtocolMessageType('Timestamp', (_message.Message,), dict(
  DESCRIPTOR = _TIMESTAMP,
  __module__ = 'EventHub_pb2'
  # @@protoc_insertion_point(class_scope:predix.eventhub.Timestamp)
  ))
_sym_db.RegisterMessage(Timestamp)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), dict(

  TagsEntry = _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), dict(
    DESCRIPTOR = _MESSAGE_TAGSENTRY,
    __module__ = 'EventHub_pb2'
    # @@protoc_insertion_point(class_scope:predix.eventhub.Message.TagsEntry)
    ))
  ,
  DESCRIPTOR = _MESSAGE,
  __module__ = 'EventHub_pb2'
  # @@protoc_insertion_point(class_scope:predix.eventhub.Message)
  ))
_sym_db.RegisterMessage(Message)
_sym_db.RegisterMessage(Message.TagsEntry)

Ack = _reflection.GeneratedProtocolMessageType('Ack', (_message.Message,), dict(

  TagsEntry = _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), dict(
    DESCRIPTOR = _ACK_TAGSENTRY,
    __module__ = 'EventHub_pb2'
    # @@protoc_insertion_point(class_scope:predix.eventhub.Ack.TagsEntry)
    ))
  ,
  DESCRIPTOR = _ACK,
  __module__ = 'EventHub_pb2'
  # @@protoc_insertion_point(class_scope:predix.eventhub.Ack)
  ))
_sym_db.RegisterMessage(Ack)
_sym_db.RegisterMessage(Ack.TagsEntry)

Messages = _reflection.GeneratedProtocolMessageType('Messages', (_message.Message,), dict(
  DESCRIPTOR = _MESSAGES,
  __module__ = 'EventHub_pb2'
  # @@protoc_insertion_point(class_scope:predix.eventhub.Messages)
  ))
_sym_db.RegisterMessage(Messages)

PublishRequest = _reflection.GeneratedProtocolMessageType('PublishRequest', (_message.Message,), dict(
  DESCRIPTOR = _PUBLISHREQUEST,
  __module__ = 'EventHub_pb2'
  # @@protoc_insertion_point(class_scope:predix.eventhub.PublishRequest)
  ))
_sym_db.RegisterMessage(PublishRequest)

SubscriptionMessage = _reflection.GeneratedProtocolMessageType('SubscriptionMessage', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIPTIONMESSAGE,
  __module__ = 'EventHub_pb2'
  # @@protoc_insertion_point(class_scope:predix.eventhub.SubscriptionMessage)
  ))
_sym_db.RegisterMessage(SubscriptionMessage)

PublishResponse = _reflection.GeneratedProtocolMessageType('PublishResponse', (_message.Message,), dict(
  DESCRIPTOR = _PUBLISHRESPONSE,
  __module__ = 'EventHub_pb2'
  # @@protoc_insertion_point(class_scope:predix.eventhub.PublishResponse)
  ))
_sym_db.RegisterMessage(PublishResponse)

SubscriptionResponse = _reflection.GeneratedProtocolMessageType('SubscriptionResponse', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIPTIONRESPONSE,
  __module__ = 'EventHub_pb2'
  # @@protoc_insertion_point(class_scope:predix.eventhub.SubscriptionResponse)
  ))
_sym_db.RegisterMessage(SubscriptionResponse)

SubscriptionAcks = _reflection.GeneratedProtocolMessageType('SubscriptionAcks', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIPTIONACKS,
  __module__ = 'EventHub_pb2'
  # @@protoc_insertion_point(class_scope:predix.eventhub.SubscriptionAcks)
  ))
_sym_db.RegisterMessage(SubscriptionAcks)

SubscriptionRequest = _reflection.GeneratedProtocolMessageType('SubscriptionRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIPTIONREQUEST,
  __module__ = 'EventHub_pb2'
  # @@protoc_insertion_point(class_scope:predix.eventhub.SubscriptionRequest)
  ))
_sym_db.RegisterMessage(SubscriptionRequest)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\026com.ge.predix.eventhubB\017EventHubServiceP\001'))
_MESSAGE_TAGSENTRY.has_options = True
_MESSAGE_TAGSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_ACK_TAGSENTRY.has_options = True
_ACK_TAGSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))

_PUBLISHER = _descriptor.ServiceDescriptor(
  name='Publisher',
  full_name='predix.eventhub.Publisher',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=1165,
  serialized_end=1257,
  methods=[
  _descriptor.MethodDescriptor(
    name='send',
    full_name='predix.eventhub.Publisher.send',
    index=0,
    containing_service=None,
    input_type=_PUBLISHREQUEST,
    output_type=_PUBLISHRESPONSE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_PUBLISHER)

DESCRIPTOR.services_by_name['Publisher'] = _PUBLISHER


_SUBSCRIBER = _descriptor.ServiceDescriptor(
  name='Subscriber',
  full_name='predix.eventhub.Subscriber',
  file=DESCRIPTOR,
  index=1,
  options=None,
  serialized_start=1260,
  serialized_end=1533,
  methods=[
  _descriptor.MethodDescriptor(
    name='receive',
    full_name='predix.eventhub.Subscriber.receive',
    index=0,
    containing_service=None,
    input_type=_SUBSCRIPTIONREQUEST,
    output_type=_MESSAGE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='receiveWithAcks',
    full_name='predix.eventhub.Subscriber.receiveWithAcks',
    index=1,
    containing_service=None,
    input_type=_SUBSCRIPTIONRESPONSE,
    output_type=_MESSAGE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='subscribe',
    full_name='predix.eventhub.Subscriber.subscribe',
    index=2,
    containing_service=None,
    input_type=_SUBSCRIPTIONACKS,
    output_type=_SUBSCRIPTIONMESSAGE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_SUBSCRIBER)

DESCRIPTOR.services_by_name['Subscriber'] = _SUBSCRIBER

try:
  # THESE ELEMENTS WILL BE DEPRECATED.
  # Please use the generated *_pb2_grpc.py files instead.
  import grpc
  from grpc.beta import implementations as beta_implementations
  from grpc.beta import interfaces as beta_interfaces
  from grpc.framework.common import cardinality
  from grpc.framework.interfaces.face import utilities as face_utilities


  class PublisherStub(object):
    """Publisher service definition
    """

    def __init__(self, channel):
      """Constructor.

      Args:
        channel: A grpc.Channel.
      """
      self.send = channel.stream_stream(
          '/predix.eventhub.Publisher/send',
          request_serializer=PublishRequest.SerializeToString,
          response_deserializer=PublishResponse.FromString,
          )


  class PublisherServicer(object):
    """Publisher service definition
    """

    def send(self, request_iterator, context):
      """Send message to topic. Topic name will be in URI
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')


  def add_PublisherServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'send': grpc.stream_stream_rpc_method_handler(
            servicer.send,
            request_deserializer=PublishRequest.FromString,
            response_serializer=PublishResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'predix.eventhub.Publisher', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


  class SubscriberStub(object):
    """Subscriber service definition
    """

    def __init__(self, channel):
      """Constructor.

      Args:
        channel: A grpc.Channel.
      """
      self.receive = channel.unary_stream(
          '/predix.eventhub.Subscriber/receive',
          request_serializer=SubscriptionRequest.SerializeToString,
          response_deserializer=Message.FromString,
          )
      self.receiveWithAcks = channel.stream_stream(
          '/predix.eventhub.Subscriber/receiveWithAcks',
          request_serializer=SubscriptionResponse.SerializeToString,
          response_deserializer=Message.FromString,
          )
      self.subscribe = channel.stream_stream(
          '/predix.eventhub.Subscriber/subscribe',
          request_serializer=SubscriptionAcks.SerializeToString,
          response_deserializer=SubscriptionMessage.FromString,
          )


  class SubscriberServicer(object):
    """Subscriber service definition
    """

    def receive(self, request, context):
      """Receive message from a topic, as a subscriber
      """
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def receiveWithAcks(self, request_iterator, context):
      # missing associated documentation comment in .proto file
      pass
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')

    def subscribe(self, request_iterator, context):
      # missing associated documentation comment in .proto file
      pass
      context.set_code(grpc.StatusCode.UNIMPLEMENTED)
      context.set_details('Method not implemented!')
      raise NotImplementedError('Method not implemented!')


  def add_SubscriberServicer_to_server(servicer, server):
    rpc_method_handlers = {
        'receive': grpc.unary_stream_rpc_method_handler(
            servicer.receive,
            request_deserializer=SubscriptionRequest.FromString,
            response_serializer=Message.SerializeToString,
        ),
        'receiveWithAcks': grpc.stream_stream_rpc_method_handler(
            servicer.receiveWithAcks,
            request_deserializer=SubscriptionResponse.FromString,
            response_serializer=Message.SerializeToString,
        ),
        'subscribe': grpc.stream_stream_rpc_method_handler(
            servicer.subscribe,
            request_deserializer=SubscriptionAcks.FromString,
            response_serializer=SubscriptionMessage.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        'predix.eventhub.Subscriber', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


  class BetaPublisherServicer(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """Publisher service definition
    """
    def send(self, request_iterator, context):
      """Send message to topic. Topic name will be in URI
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


  class BetaPublisherStub(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """Publisher service definition
    """
    def send(self, request_iterator, timeout, metadata=None, with_call=False, protocol_options=None):
      """Send message to topic. Topic name will be in URI
      """
      raise NotImplementedError()


  def beta_create_Publisher_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_deserializers = {
      ('predix.eventhub.Publisher', 'send'): PublishRequest.FromString,
    }
    response_serializers = {
      ('predix.eventhub.Publisher', 'send'): PublishResponse.SerializeToString,
    }
    method_implementations = {
      ('predix.eventhub.Publisher', 'send'): face_utilities.stream_stream_inline(servicer.send),
    }
    server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
    return beta_implementations.server(method_implementations, options=server_options)


  def beta_create_Publisher_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_serializers = {
      ('predix.eventhub.Publisher', 'send'): PublishRequest.SerializeToString,
    }
    response_deserializers = {
      ('predix.eventhub.Publisher', 'send'): PublishResponse.FromString,
    }
    cardinalities = {
      'send': cardinality.Cardinality.STREAM_STREAM,
    }
    stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
    return beta_implementations.dynamic_stub(channel, 'predix.eventhub.Publisher', cardinalities, options=stub_options)


  class BetaSubscriberServicer(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """Subscriber service definition
    """
    def receive(self, request, context):
      """Receive message from a topic, as a subscriber
      """
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def receiveWithAcks(self, request_iterator, context):
      # missing associated documentation comment in .proto file
      pass
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
    def subscribe(self, request_iterator, context):
      # missing associated documentation comment in .proto file
      pass
      context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


  class BetaSubscriberStub(object):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This class was generated
    only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0."""
    """Subscriber service definition
    """
    def receive(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
      """Receive message from a topic, as a subscriber
      """
      raise NotImplementedError()
    def receiveWithAcks(self, request_iterator, timeout, metadata=None, with_call=False, protocol_options=None):
      # missing associated documentation comment in .proto file
      pass
      raise NotImplementedError()
    def subscribe(self, request_iterator, timeout, metadata=None, with_call=False, protocol_options=None):
      # missing associated documentation comment in .proto file
      pass
      raise NotImplementedError()


  def beta_create_Subscriber_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_deserializers = {
      ('predix.eventhub.Subscriber', 'receive'): SubscriptionRequest.FromString,
      ('predix.eventhub.Subscriber', 'receiveWithAcks'): SubscriptionResponse.FromString,
      ('predix.eventhub.Subscriber', 'subscribe'): SubscriptionAcks.FromString,
    }
    response_serializers = {
      ('predix.eventhub.Subscriber', 'receive'): Message.SerializeToString,
      ('predix.eventhub.Subscriber', 'receiveWithAcks'): Message.SerializeToString,
      ('predix.eventhub.Subscriber', 'subscribe'): SubscriptionMessage.SerializeToString,
    }
    method_implementations = {
      ('predix.eventhub.Subscriber', 'receive'): face_utilities.unary_stream_inline(servicer.receive),
      ('predix.eventhub.Subscriber', 'receiveWithAcks'): face_utilities.stream_stream_inline(servicer.receiveWithAcks),
      ('predix.eventhub.Subscriber', 'subscribe'): face_utilities.stream_stream_inline(servicer.subscribe),
    }
    server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
    return beta_implementations.server(method_implementations, options=server_options)


  def beta_create_Subscriber_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
    """The Beta API is deprecated for 0.15.0 and later.

    It is recommended to use the GA API (classes and functions in this
    file not marked beta) for all further purposes. This function was
    generated only to ease transition from grpcio<0.15.0 to grpcio>=0.15.0"""
    request_serializers = {
      ('predix.eventhub.Subscriber', 'receive'): SubscriptionRequest.SerializeToString,
      ('predix.eventhub.Subscriber', 'receiveWithAcks'): SubscriptionResponse.SerializeToString,
      ('predix.eventhub.Subscriber', 'subscribe'): SubscriptionAcks.SerializeToString,
    }
    response_deserializers = {
      ('predix.eventhub.Subscriber', 'receive'): Message.FromString,
      ('predix.eventhub.Subscriber', 'receiveWithAcks'): Message.FromString,
      ('predix.eventhub.Subscriber', 'subscribe'): SubscriptionMessage.FromString,
    }
    cardinalities = {
      'receive': cardinality.Cardinality.UNARY_STREAM,
      'receiveWithAcks': cardinality.Cardinality.STREAM_STREAM,
      'subscribe': cardinality.Cardinality.STREAM_STREAM,
    }
    stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
    return beta_implementations.dynamic_stub(channel, 'predix.eventhub.Subscriber', cardinalities, options=stub_options)
except ImportError:
  pass
# @@protoc_insertion_point(module_scope)




import predix.security.uaa
import predix.admin.service


class AnalyticsFramework(predix.admin.spaces.SpaceManager):
    """
    Analytics framework.
    """
    def __init__(self, plan_name=None, name=None, uaa=None, *args, **kwargs):
        super(AnalyticsFramework, self).__init__(*args, **kwargs)
        self.service_name = 'predix-analytics-framework'
        self.plan_name = plan_name or 'Free'
        self.service = predix.admin.service.PredixService(self.service_name,
                self.plan_name, name=name, uaa=uaa)

    def exists(self):
        """
        Returns whether or not this service already exists.
        """
        return self.service.exists()

    def create(self, asset, timeseries, client_id, client_secret,
            ui_client_id=None, ui_client_secret=None):
        """
        Create an instance of the Analytics Framework Service with the
        typical starting settings.

        If not provided, will reuse the runtime client for the ui
        as well.
        """
        assert isinstance(asset, predix.admin.asset.Asset), \
            "Require an existing predix.admin.asset.Asset instance"
        assert isinstance(timeseries, predix.admin.timeseries.TimeSeries), \
            "Require an existing predix.admin.timeseries.TimeSeries instance"

        parameters = {
            'predixAssetZoneId': asset.get_zone_id(),
            'predixTimeseriesZoneId': timeseries.get_query_zone_id(),
            'runtimeClientId': client_id,
            'runtimeClientSecret': client_secret,
            'uiClientId': ui_client_id or client_id,
            'uiClientSecret': ui_client_secret or client_secret,
            'uiDomainPrefix': self.service.name,
        }

        self.service.create(parameters=parameters)




from setuptools import setup, find_packages

install_requires = [
        "python-dateutil==2.6.0",
        "boto3",
        "PyYAML",
        "requests",
        "cryptography",
        "redis",
        "sqlalchemy",
        "six",
        "future",
        "psycopg2",
        "websocket",
        "websocket-client"
    ]

setup_requires = [
    ]

docs_require = [
        "sphinx",
        "sphinx-autobuild",
        "sphinxcontrib-httpdomain",
        "sphinx_rtd_theme",
        "recommonmark",
    ]

tests_require = [
    #    "mock",    # only for Python < 3.3
    ]

long_description = 'See GitHub README.rst for more details.'
with open('README.rst') as file:
   long_description = file.read()

setup(
        name="predix",
        version="1.0.0",
        author="Jayson DeLancey",
        author_email="jayson.delancey@ge.com",
        description="Python Client SDK for Predix Services",
        long_description=long_description,
        setup_requires=setup_requires,
        install_requires=install_requires,
        package_data={
            '': ['*.md', '*.rst'],
            },
        packages=find_packages(exclude=['test', 'test.*']),
        test_suite="test",
        tests_require=tests_require,
        entry_points={
            'console_scripts': [
                ]
        },
        keywords=['predix', 'ge', 'asset', 'analytics'],
        url="https://github.com/PredixDev/predixpy",
        classifiers=[
            'Intended Audience :: Developers',
            'Natural Language :: English',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3.6',
            'License :: OSI Approved :: BSD License',
            'Development Status :: 3 - Alpha']
    )



import os

import predix.config
import predix.security.uaa
import predix.admin.service
import predix.data.eventhub


class EventHub(object):
    """
   Event Hub is a publisher/subscriber framework for getting information in, out and around the predix cloud
    """

    def __init__(self, plan_name=None, name=None, uaa=None, *args, **kwargs):
        self.service_name = 'predix-event-hub'
        self.plan_name = plan_name or 'Tiered'
        self.use_class = predix.data.eventhub.Eventhub

        self.service = predix.admin.service.PredixService(self.service_name,
                                                          self.plan_name, name=name, uaa=uaa)

    def exists(self):
        """
        Returns whether or not this service already exists.
        """
        return self.service.exists()

    def create(self):
        """
        Create an instance of the Time Series Service with the typical
        starting settings.
        """
        self.service.create()

        os.environ[predix.config.get_env_key(self.use_class, 'host')] = self.get_eventhub_host()
        os.environ[predix.config.get_env_key(self.use_class, 'port')] = self.get_eventhub_grpc_port()
        os.environ[predix.config.get_env_key(self.use_class, 'wss_publish_uri')] = self.get_publish_wss_uri()
        os.environ[predix.config.get_env_key(self.use_class, 'zone_id')] = self.get_zone_id()

    def grant_client(self, client_id, publish=False, subscribe=False, publish_protocol=None, publish_topics=None,
                     subscribe_topics=None, scope_prefix='predix-event-hub', **kwargs):
        """
        Grant the given client id all the scopes and authorities
        needed to work with the eventhub service.
        """
        scopes = ['openid']
        authorities = ['uaa.resource']

        zone_id = self.get_zone_id()
        # always must be part of base user scope
        scopes.append('%s.zones.%s.user' % (scope_prefix, zone_id))
        authorities.append('%s.zones.%s.user' % (scope_prefix, zone_id))

        if publish_topics is not None or subscribe_topics is not None:
            raise Exception("multiple topics are not currently available in preidx-py")

        if publish_topics is None:
            publish_topics = ['topic']

        if subscribe_topics is None:
            subscribe_topics = ['topic']

        if publish:
            # we are granting just the default topic
            if publish_protocol is None:
                scopes.append('%s.zones.%s.grpc.publish' % (scope_prefix, zone_id))
                authorities.append('%s.zones.%s.grpc.publish' % (scope_prefix, zone_id))
                scopes.append('%s.zones.%s.wss.publish' % (scope_prefix, zone_id))
                authorities.append('%s.zones.%s.wss.publish' % (scope_prefix, zone_id))

            else:
                scopes.append('%s.zones.%s.%s.publish' % (scope_prefix, zone_id, publish_protocol))
                authorities.append('%s.zones.%s.%s.publish' % (scope_prefix, zone_id, publish_protocol))

            # we are requesting multiple topics
            for topic in publish_topics:
                if publish_protocol is None:
                    scopes.append('%s.zones.%s.%s.grpc.publish' % (scope_prefix, zone_id, topic))
                    scopes.append('%s.zones.%s.%s.wss.publish' % (scope_prefix, zone_id, topic))
                    scopes.append('%s.zones.%s.%s.user' % (scope_prefix, zone_id, topic))
                    authorities.append('%s.zones.%s.%s.grpc.publish' % (scope_prefix, zone_id, topic))
                    authorities.append('%s.zones.%s.%s.wss.publish' % (scope_prefix, zone_id, topic))
                    authorities.append('%s.zones.%s.%s.user' % (scope_prefix, zone_id, topic))
                else:
                    scopes.append('%s.zones.%s.%s.%s.publish' % (scope_prefix, zone_id, topic, publish_protocol))
                    authorities.append('%s.zones.%s.%s.%s.publish' % (scope_prefix, zone_id, topic, publish_protocol))
        if subscribe:
            # we are granting just the default topic
            scopes.append('%s.zones.%s.grpc.subscribe' % (scope_prefix, zone_id))
            authorities.append('%s.zones.%s.grpc.subscribe' % (scope_prefix, zone_id))

            # we are requesting multiple topics
            for topic in subscribe_topics:
                scopes.append('%s.zones.%s.%s.grpc.subscribe' % (scope_prefix, zone_id, topic))
                authorities.append('%s.zones.%s.%s.grpc.subscribe' % (scope_prefix, zone_id, topic))

        self.service.uaa.uaac.update_client_grants(client_id, scope=scopes,
                                                   authorities=authorities)

        return self.service.uaa.uaac.get_client(client_id)

    def get_eventhub_host(self):
        """
        returns the publish grpc endpoint for ingestion.
        """
        for protocol in self.service.settings.data['publish']['protocol_details']:
            if protocol['protocol'] == 'grpc':
                return protocol['uri'][0:protocol['uri'].index(':')]

    def get_eventhub_grpc_port(self):
        for protocol in self.service.settings.data['publish']['protocol_details']:
            if protocol['protocol'] == 'grpc':
                return str(protocol['uri'][(protocol['uri'].index(':') + 1):])

    def get_publish_wss_uri(self):
        """
        returns the publish grpc endpoint for ingestion.

        """
        for protocol in self.service.settings.data['publish']['protocol_details']:
            if protocol['protocol'] == 'wss':
                return protocol['uri']

    def get_zone_id(self):
        return self.service.settings.data['publish']['zone-http-header-value']

    def get_subscribe_uri(self):
        return self.service.settings.data['subscribe']['protocol_details'][0]['uri']

    def make_topic(self, broker_uri, topic_name):
        raise Exception('make topic has not been implemented yet')

    def add_to_manifest(self, manifest):
        """
        Add useful details to the manifest about this service
        so that it can be used in an application.

        :param manifest: An predix.admin.app.Manifest object
            instance that manages reading/writing manifest config
            for a cloud foundry app.
        """
        # Add this service to list of services
        manifest.add_service(self.service.name)

        # Add environment variables
        manifest.add_env_var(predix.config.get_env_key(self.use_class, 'host'), self.get_eventhub_host())
        manifest.add_env_var(predix.config.get_env_key(self.use_class, 'port'), self.get_eventhub_grpc_port())
        manifest.add_env_var(predix.config.get_env_key(self.use_class, 'wss_publish_uri'), self.get_publish_wss_uri())
        manifest.add_env_var(predix.config.get_env_key(self.use_class, 'zone_id'), self.get_zone_id())

        manifest.write_manifest()



import json
import logging
import os
import threading
import time

import grpc

import predix.config
import predix.service
from predix.data.eventhub import Health_pb2_grpc
from predix.data.eventhub import Health_pb2
from predix.data.eventhub.publisher import PublisherConfig, Publisher
from predix.data.eventhub.subscriber import Subscriber


class EventHubException(Exception):
    def __init__(self, str):
        Exception.__init__(self, str)


class Eventhub(object):
    """
    Client library for working with the Eventhub Service
    Provide it with the id, and the config you need for each thing
    if that feature is not required then leave config as None
    """

    def __init__(self,
                 publish_config=None,
                 subscribe_config=None,
                 ):
        # initialize the publisher and subscriber
        # only build shared grpc channel if required
        self._ws = None
        self._channel = None
        self._run_health_checker = True
        if publish_config is not None:
            # make the channel
            if publish_config.protocol == PublisherConfig.Protocol.GRPC:
                self._init_channel()
            self.publisher = Publisher(eventhub_client=self, channel=self._channel, config=publish_config)

        if subscribe_config is not None:
            if self._channel is None:
                self._init_channel()
            self.subscriber = Subscriber(self, channel=self._channel, config=subscribe_config)

    def shutdown(self):
        """
        Shutdown the client, shutdown the sub clients and stop the health checker
        :return: None
        """
        self._run_health_checker = False
        if self.publisher is not None:
            self.publisher.shutdown()

        if self.subscriber is not None:
            self.subscriber.shutdown()

    def _get_host(self):
        if 'VCAP_SERVICES' in os.environ:
            services = json.loads(os.getenv('VCAP_SERVICES'))
            host = services['predix-event-hub'][0]['credentials']['publish']['protocol_details']['uri']
            return host[:host.index(':')]
        return self.get_service_env_value('host')

    def _get_grpc_port(self):
        if 'VCAP_SERVICES' in os.environ:
            services = json.loads(os.getenv('VCAP_SERVICES'))
            host = services['predix-event-hub'][0]['credentials']['publish']['protocol_details']['uri']
            return host[host.index(':')+1:]
        return self.get_service_env_value('port')

    def get_service_env_value(self, key):
        """
        Get a env variable as defined by the service admin
        :param key: the base of the key to use
        :return: the env if it exists
        """
        service_key = predix.config.get_env_key(self, key)
        value = os.environ[service_key]
        if not value:
            raise ValueError("%s env unset" % key)
        return value

    def _init_channel(self):
        """
        build the grpc channel used for both publisher and subscriber
        :return: None
        """
        host = self._get_host()
        port = self._get_grpc_port()

        if 'TLS_PEM_FILE' in os.environ:
            with open(os.environ['TLS_PEM_FILE'], mode='rb') as f:  # b is important -> binary
                file_content = f.read()
            credentials = grpc.ssl_channel_credentials(root_certificates=file_content)
        else:
            credentials = grpc.ssl_channel_credentials()

        self._channel = grpc.secure_channel(host + ":" + port, credentials=credentials)
        self._init_health_checker()

    def _init_health_checker(self):
        """
        start the health checker stub and start a thread to ping it every 30 seconds
        :return: None
        """
        stub = Health_pb2_grpc.HealthStub(channel=self._channel)
        self._health_check = stub.Check
        health_check_thread = threading.Thread(target=self._health_check_thread)
        health_check_thread.daemon = True
        health_check_thread.start()

    def _health_check_thread(self):
        """
        Health checker thread that pings the service every 30 seconds
        :return: None
        """
        while self._run_health_checker:
            response = self._health_check(Health_pb2.HealthCheckRequest(service='predix-event-hub.grpc.health'))
            logging.debug('received health check: ' + str(response))
            time.sleep(30)
        return

    class GrpcManager:
        """
        Class for managing GRPC calls by turing the generators grpc uses into function calls
        This allows the sdk to man in the middle the messages
        """
        def __init__(self, stub_call, on_msg_callback, metadata, tx_stream=True, initial_message=None):
            """
            :param stub_call: the call on the grpc stub to build the generator on
            :param on_msg_callback: the callback to pass any received functions on
            :param metadata: metadata to attach to the stub call
            """
            self._tx_stream = tx_stream
            self._stub_call = stub_call
            self._on_msg_callback = on_msg_callback
            self._metadata = metadata
            self._initial_message = initial_message
            self._grpc_rx_thread = threading.Thread(target=self._grpc_rx_receiver)
            self._grpc_rx_thread.daemon = True
            self._grpc_rx_thread.start()
            self._grpc_tx_queue = []
            self._run_generator = True
            time.sleep(1)

        def send_message(self, tx_message):
            """
            Add a message onto the tx queue to be sent on the stub
            :param tx_message:
            :return: None
            """
            self._grpc_tx_queue.append(tx_message)

        def _grpc_rx_receiver(self):
            """
            Blocking Function that opens the stubs generator and pass any messages onto the callback
            :return: None
            """
            logging.debug("grpc rx stream metadata: " + str(self._metadata))
            if self._tx_stream:
                if self._initial_message is not None:
                    self.send_message(self._initial_message)
                msgs = self._stub_call(request_iterator=self._grpc_tx_generator(), metadata=self._metadata)
            else:
                msgs = self._stub_call(self._initial_message, metadata=self._metadata)

            for m in msgs:
                self._on_msg_callback(m)

        def stop_generator(self):
            """
            Call this to close the generator
            :return:
            """
            logging.debug('stopping generator')
            self._run_generator = False

        def _grpc_tx_generator(self):
            """
            the generator taking and messages added to the grpc_tx_queue
            and yield them to grpc
            :return: grpc messages
            """
            while self._run_generator:
                while len(self._grpc_tx_queue) != 0:
                    yield self._grpc_tx_queue.pop(0)
            return





import os

from future.moves.urllib.parse import urlparse

import predix.config
import predix.security.uaa
import predix.admin.service
import predix.data.timeseries


class TimeSeries(object):
    """
    Time Series provides persistence of data values over time.
    """
    def __init__(self, plan_name=None, name=None, uaa=None, *args, **kwargs):
        super(TimeSeries, self).__init__(*args, **kwargs)
        self.service_name = 'predix-timeseries'
        self.plan_name = plan_name or 'Free'
        self.use_class = predix.data.timeseries.TimeSeries

        self.service = predix.admin.service.PredixService(self.service_name,
                self.plan_name, name=name, uaa=uaa)

    def exists(self):
        """
        Returns whether or not this service already exists.
        """
        return self.service.exists()

    def create(self):
        """
        Create an instance of the Time Series Service with the typical
        starting settings.
        """
        self.service.create()

        predix.config.set_env_value(self.use_class, 'ingest_uri',
                self.get_ingest_uri())
        predix.config.set_env_value(self.use_class, 'ingest_zone_id',
                self.get_ingest_zone_id())

        predix.config.set_env_value(self.use_class, 'query_uri',
                self.get_query_uri())
        predix.config.set_env_value(self.use_class, 'query_zone_id',
                self.get_query_zone_id())

    def grant_client(self, client_id, read=True, write=True):
        """
        Grant the given client id all the scopes and authorities
        needed to work with the timeseries service.
        """
        scopes = ['openid']
        authorities = ['uaa.resource']

        if write:
            for zone in self.service.settings.data['ingest']['zone-token-scopes']:
                scopes.append(zone)
                authorities.append(zone)

        if read:
            for zone in self.service.settings.data['query']['zone-token-scopes']:
                scopes.append(zone)
                authorities.append(zone)

        self.service.uaa.uaac.update_client_grants(client_id, scope=scopes,
                authorities=authorities)

        return self.service.uaa.uaac.get_client(client_id)

    def get_ingest_zone_id(self):
        """
        Returns the Predix-Zone-Id used for ingesting data with this
        service.
        """
        return self.service.settings.data['ingest']['zone-http-header-value']

    def get_query_zone_id(self):
        """
        Return the Predix-Zone-Id used for queries on data with this
        service.
        """
        return self.service.settings.data['query']['zone-http-header-value']

    def get_ingest_uri(self):
        """
        Return the uri used for ingesting data into time series
        """
        return self.service.settings.data['ingest']['uri']

    def get_query_uri(self):
        """
        Return the uri used for queries on time series data.
        """
        # Query URI has extra path we don't want so strip it off here
        query_uri = self.service.settings.data['query']['uri']
        query_uri = urlparse(query_uri)
        return query_uri.scheme + '://' + query_uri.netloc

    def add_to_manifest(self, manifest):
        """
        Add useful details to the manifest about this service
        so that it can be used in an application.

        :param manifest: An predix.admin.app.Manifest object
            instance that manages reading/writing manifest config
            for a cloud foundry app.
        """
        # Add this service to list of services
        manifest.add_service(self.service.name)

        # Add environment variables
        uri = predix.config.get_env_key(self.use_class, 'ingest_uri')
        manifest.add_env_var(uri, self.get_ingest_uri())

        zone_id = predix.config.get_env_key(self.use_class, 'ingest_zone_id')
        manifest.add_env_var(zone_id, self.get_ingest_zone_id())

        uri = predix.config.get_env_key(self.use_class, 'query_uri')
        manifest.add_env_var(uri, self.get_query_uri())

        zone_id = predix.config.get_env_key(self.use_class, 'query_zone_id')
        manifest.add_env_var(zone_id, self.get_query_zone_id())

        manifest.write_manifest()




import os
import boto3
import logging
import json

import predix.service
import predix.config


class BlobStore(object):
    """
    The BlobStore is the place to store Binary Large Objects, ie. files that
    could be images, csv files, cad files, pdf files, etc.

    .. important::

       This service will only work from the Predix Cloud -- Firewall will block
       any traffic not originating from within the Predix environment.

    Underlying BlobStore is the AWS S3 service so you will need to be familiar
    with the boto3 library from AWS to learn how to work with buckets.  A few
    methods are provided for common patterns you can use for reference.

    :param host: Host address for blob store.


    """
    def __init__(self, host=None, access_key_id=None, secret_access_key=None,
            bucket_name=None, *args, **kwargs):
        super(BlobStore, self).__init__(*args, **kwargs)

        if not predix.config.is_cf_env():
            raise predix.config.PredixCloudRequiredError()

        self.host = host or self._get_host()
        self.access_key_id = access_key_id or self._get_access_key_id()
        self.secret_access_key = secret_access_key or self._get_secret_access_key()
        self.bucket_name = bucket_name or self._get_bucket_name()

        self.session = boto3.session.Session(
                aws_access_key_id=self.access_key_id,
                aws_secret_access_key=self.secret_access_key)

        config = boto3.session.Config(signature_version='s3', s3={
                'addressing_style': 'virtual'})
        self.client = self.session.client('s3', endpoint_url=self.host,
                config=config)

    def _get_host(self):
        """
        Returns the host address for an instance of Blob Store service from
        environment inspection.
        """
        if 'VCAP_SERVICES' in os.environ:
            services = json.loads(os.getenv('VCAP_SERVICES'))
            host = services['predix-blobstore'][0]['credentials']['host']
        else:
            host = predix.config.get_env_value(self, 'host')

        # Protocol may not always be included in host setting
        if 'https://' not in host:
            host = 'https://' + host

        return host

    def _get_access_key_id(self):
        """
        Returns the access key for an instance of Blob Store service from
        environment inspection.
        """
        if 'VCAP_SERVICES' in os.environ:
            services = json.loads(os.getenv('VCAP_SERVICES'))
            return services['predix-blobstore'][0]['credentials']['access_key_id']
        else:
            return predix.config.get_env_value(self, 'access_key_id')

    def _get_secret_access_key(self):
        """
        Returns the secret access key for an instance of Blob Store service from
        environment inspection.
        """
        if 'VCAP_SERVICES' in os.environ:
            services = json.loads(os.getenv('VCAP_SERVICES'))
            return services['predix-blobstore'][0]['credentials']['secret_access_key']
        else:
            return predix.config.get_env_value(self, 'secret_access_key')

    def _get_bucket_name(self):
        """
        Returns the bucket name for an instance of Blob Store service from
        environment inspection.
        """
        if 'VCAP_SERVICES' in os.environ:
            services = json.loads(os.getenv('VCAP_SERVICES'))
            return services['predix-blobstore'][0]['credentials']['bucket_name']
        else:
            return predix.config.get_env_value(self, 'bucket_name')

    def list_buckets(self, *args, **kwargs):
        """
        This method is primarily for illustration and just calls the boto3
        client implementation of list_buckets directly but is a common task for
        first time Predix BlobStore users.
        """
        return self.client.list_buckets(**kwargs)

    def list_objects(self, bucket_name=None, **kwargs):
        """
        This method is primarily for illustration and just calls the 
        boto3 client implementation of list_objects but is a common task
        for first time Predix BlobStore users.
        """
        if not bucket_name: bucket_name = self.bucket_name
        return self.client.list_objects(Bucket=bucket_name, **kwargs)

    def upload_file(self, src_filepath, dest_filename=None, bucket_name=None,
            **kwargs):
        """
        This method is primarily for illustration and just calls the 
        boto3 client implementation of upload_file but is a common task
        for first time Predix BlobStore users.
        """
        if not bucket_name: bucket_name = self.bucket_name
        if not dest_filename: dest_filename = src_filepath
        return self.client.upload_file(src_filepath, bucket_name,
                dest_filename, **kwargs)




import os
import json
import logging
import requests

import predix.app
import predix.security.uaa


class Service(object):
    """
    General class for making REST calls to Predix multi-tenant
    services that require a Predix-Zone-Id and Bearer token.
    """
    def __init__(self, zone, *args, **kwargs):
        super(Service, self).__init__(*args, **kwargs)

        self.zone = zone

        self.uaa = predix.security.uaa.UserAccountAuthentication()
        self.session = requests.Session()

        self._auto_authenticate()

    def __del__(self):
        self.session.close()

    def _auto_authenticate(self):
        """
        If we are in an app context we can authenticate immediately.
        """
        client_id = predix.config.get_env_value(predix.app.Manifest, 'client_id')
        client_secret = predix.config.get_env_value(predix.app.Manifest, 'client_secret')

        if client_id and client_secret:
            logging.info("Automatically authenticated as %s" % (client_id))
            self.uaa.authenticate(client_id, client_secret)

    def _get_bearer_token(self):
        """
        For application client will return a valid bearer token.
        """
        return 'Bearer ' + self.uaa.get_token()

    def _get_headers(self):
        """
        Standard Predix service headers.
        """
        headers = {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
            'Predix-Zone-Id': self.zone,
            'Authorization': self._get_bearer_token()
        }
        return headers

    def _get(self, uri, params=None, headers=None):
        """
        Simple GET request for a given path.
        """
        if not headers:
            headers = self._get_headers()

        logging.debug("URI=" + str(uri))
        logging.debug("HEADERS=" + str(headers))

        response = self.session.get(uri, headers=headers, params=params)
        logging.debug("STATUS=" + str(response.status_code))
        if response.status_code == 200:
            return response.json()
        else:
            logging.error(b"ERROR=" + response.content)
            response.raise_for_status()

    def _post(self, uri, data):
        """
        Simple POST request for a given path.
        """
        headers = self._get_headers()

        logging.debug("URI=" + str(uri))
        logging.debug("BODY=" + json.dumps(data))

        response = self.session.post(uri, headers=headers,
                data=json.dumps(data))
        if response.status_code in [200, 204]:
            try:
                return response.json()
            except ValueError:
                return "{}"
        else:
            logging.error(response.content)
            response.raise_for_status()

    def _put(self, uri, data):
        """
        Simple PUT operation for a given path.
        """
        headers = self._get_headers()

        logging.debug("URI=" + str(uri))
        logging.debug("BODY=" + json.dumps(data))

        response = self.session.put(uri, headers=headers,
                data=json.dumps(data))
        if response.status_code in [201, 204]:
            return data
        else:
            logging.error(response.content)
            response.raise_for_status()

    def _delete(self, uri):
        """
        Simple DELETE operation for a given path.
        """
        headers = self._get_headers()

        response = self.session.delete(uri, headers=headers)

        # Will return a 204 on successful delete
        if response.status_code == 204:
            return response
        else:
            logging.error(response.content)
            response.raise_for_status()

    def _patch(self, uri, data):
        """
        Simple PATCH operation for a given path.

        The body is expected to list operations to perform to update
        the data.  Operations include:
            - add
            - remove
            - replace
            - move
            - copy
            - test

        [
             { "op": "test", "path": "/a/b/c", "value": "foo" },
        ]
        """
        headers = self._get_headers()
        response = self.session.patch(uri, headers=headers,
                data=json.dumps(data))

        # Will return a 204 on successful patch
        if response.status_code == 204:
            return response
        else:
            logging.error(response.content)
            response.raise_for_status()
